# GiveAGame

### Description

This is a simple game engine. 
[Project GitHub](https://www.github.com/misha-network/give_a_game)

### How to install?

1. *Open your* **terminal**.
2. *Check if* **Python** and **PIP** *are installed*.
3. *Finally run* command(**`pip install giveagame`**) in your **terminal**.

